@@ -48,6 +48,7 @@ class LookupID:
     deid_series_uid: Optional[str] = field(default=None)
     deid_sop_uid: Optional[str] = field(default=None)
     time_shift: Optional[int] = field(default=None)
+    private_tags: bool = field(default=False)
 
 
 @dataclass
@@ -112,7 +113,7 @@ class DeidentifyDataset:
         Add our UIds to de-identified data elements.
         """
         if self.lookup.deid_patient_id is None:
-            ds.PatientID = str(uuid)
+            ds.PatientID = str(uuid.uuid4())
         else:
             ds.PatientID = str(self.lookup.deid_patient_id)
 
@@ -144,19 +145,23 @@ class DeidentifyDataset:
         Add rule sets if needed in the rule_sets.
         Timedelta could be set directly in rule set - not done this way - check.
         Later rules overrule previous.
+
+        Add information to tags, that the patient identity is removed and with what method.
         """
         if self.lookup.time_shift in (0, None):
             profile = Profile(
                 rule_sets=[timeshift_custom_ruleset,
                            no_times_ruleset,  # delete all times
                            ])
+            text = ''
         else:
             profile = Profile(
                 rule_sets=[timeshift_custom_ruleset,
                            ])
+            text = '/113107'
 
-        core = Core(profile=profile,  # Create an de-identification core
-                    pixel_processor=None  # here you would add the pixel location
+        core = Core(profile=profile,        # Create an de-identification core
+                    pixel_processor=None    # here you would add the pixel location
                     )
 
         deid_content = self.add_deid_uids(ds)  # added de-identified uids to ds
@@ -168,6 +173,18 @@ class DeidentifyDataset:
             pass
 
         deid_content = self.deidentify_dates(deid_content)  # de-identified dates (not times)
+        x = deid_content
+
+        # remove private tags, because they could have identity information
+        deid_content.remove_private_tags()
+        y = deid_content
+
+        if x is not y:
+            self.lookup.private_tags = True
+
+        deid_content.PatientIdentityRemoved = 'YES'
+        deid_content.DeidentificationMethod = '{Per DICOM PS 3.15 AnnexE. Details in 0012,0064}'
+        deid_content.DeidentificationMethodCodeSequence = f'113100{text}'
 
         return FileDataset(self.lookup.filename,
                            deid_content,
